==> HTML-Menu-TreeView-0.6.3.tar.gz: HTML-Menu-TreeView-0.6.3/htdocs/style/Crystal/22/html-menu-treeview/preload.js <==
folderClosed = new Image(22,22);
folderClosed.src='/style/Crystal/22/html-menu-treeview/folderClosed.gif';
plusNodeClosed = new Image(22,22);
plusNodeClosed.src='/style/Crystal/22/html-menu-treeview/plusNodeClosed.gif';
lastPlusNodeClosed = new Image(22,22);
lastPlusNodeClosed.src='/style/Crystal/22/html-menu-treeview/lastPlusNodeClosed.gif';
clasicPlusNodeClosed = new Image(22,22);
clasicPlusNodeClosed.src='/style/Crystal/22/html-menu-treeview/clasicPlusNodeClosed.gif';
clasicLastPlusNodeClosed = new Image(22,22);
clasicLastPlusNodeClosed.src='/style/Crystal/22/html-menu-treeview/clasicLastPlusNodeClosed.gif';
folderManClosed = new Image(22,22);
folderManClosed.src='/style/Crystal/22/html-menu-treeview/folderManClosed.gif';
folderGray = new Image(22,22);
folderGray.src='/style/Crystal/22/html-menu-treeview/folderGray.gif';
folderGreen = new Image(22,22);
folderGreen.src='/style/Crystal/22/html-menu-treeview/folderGreen.gif';
folderViolet = new Image(22,22);
folderViolet.src='/style/Crystal/22/html-menu-treeview/folderViolet.gif';
folderYellowClosed = new Image(22,22);
folderYellowClosed.src='/style/Crystal/22/html-menu-treeview/folderYellowClosed.gif';
folderOrangeClosed = new Image(22,22);
folderOrangeClosed.src='/style/Crystal/22/html-menu-treeview/folderOrangeClosed.gif';
folderManClosed = new Image(22,22);
folderManClosed.src='/style/Crystal/22/html-menu-treeview/folderManClosed.gif';
folderHtmlClosed = new Image(22,22);
folderHtmlClosed.src='/style/Crystal/22/html-menu-treeview/folderHtmlClosed.gif';
folderFavoriteClosed = new Image(22,22);
folderFavoriteClosed.src='/style/Crystal/22/html-menu-treeview/folderFavoriteClosed.gif';
folderTextClosed = new Image(22,22);
folderTextClosed.src='/style/Crystal/22/html-menu-treeview/folderTextClosed.gif';
folderLockedClosed = new Image(22,22);
folderLockedClosed.src='/style/Crystal/22/html-menu-treeview/folderLockedClosed.gif';
folderCrystalClosed = new Image(22,22);
folderCrystalClosed.src='/style/Crystal/22/html-menu-treeview/folderCrystalClosed.gif';
folderVideoClosed = new Image(22,22);
folderVideoClosed.src='/style/Crystal/22/html-menu-treeview/folderVideoClosed.gif';
folderPrintClosed = new Image(22,22);
folderPrintClosed.src='/style/Crystal/22/html-menu-treeview/folderPrintClosed.gif';
folderImageClosed = new Image(22,22);
folderImageClosed.src='/style/Crystal/22/html-menu-treeview/folderImageClosed.gif';
folderSoundClosed = new Image(22,22);
folderSoundClosed.src='/style/Crystal/22/html-menu-treeview/folderSoundClosed.gif';
folderImportantClosed = new Image(22,22);
folderImportantClosed.src='/style/Crystal/22/html-menu-treeview/folderImportantClosed.gif';
folderTarClosed = new Image(22,22);
folderTarClosed.src='/style/Crystal/22/html-menu-treeview/folderTarClosed.gif';

==> HTML-Menu-TreeView-0.6.6.tar.gz: HTML-Menu-TreeView-0.6.6/htdocs/style/Crystal/22/html-menu-treeview/preload.js <==
folderClosed = new Image(22,22);
folderClosed.src='/style/Crystal/22/html-menu-treeview/folderClosed.gif';
plusNode = new Image(22,22);
plusNode.src='/style/Crystal/22/html-menu-treeview/plusNode.gif';
lastplusNode = new Image(22,22);
lastplusNode.src='/style/Crystal/22/html-menu-treeview/lastplusNode.gif';
clasicplusNode = new Image(22,22);
clasicplusNode.src='/style/Crystal/22/html-menu-treeview/clasicplusNode.gif';
clasicLastplusNode = new Image(22,22);
clasicLastplusNode.src='/style/Crystal/22/html-menu-treeview/clasicLastplusNode.gif';
folderManClosed = new Image(22,22);
folderManClosed.src='/style/Crystal/22/html-menu-treeview/folderManClosed.gif';
folderGray = new Image(22,22);
folderGray.src='/style/Crystal/22/html-menu-treeview/folderGray.gif';
folderGreen = new Image(22,22);
folderGreen.src='/style/Crystal/22/html-menu-treeview/folderGreen.gif';
folderViolet = new Image(22,22);
folderViolet.src='/style/Crystal/22/html-menu-treeview/folderViolet.gif';
folderYellowClosed = new Image(22,22);
folderYellowClosed.src='/style/Crystal/22/html-menu-treeview/folderYellowClosed.gif';
folderOrangeClosed = new Image(22,22);
folderOrangeClosed.src='/style/Crystal/22/html-menu-treeview/folderOrangeClosed.gif';
folderManClosed = new Image(22,22);
folderManClosed.src='/style/Crystal/22/html-menu-treeview/folderManClosed.gif';
folderHtmlClosed = new Image(22,22);
folderHtmlClosed.src='/style/Crystal/22/html-menu-treeview/folderHtmlClosed.gif';
folderFavoriteClosed = new Image(22,22);
folderFavoriteClosed.src='/style/Crystal/22/html-menu-treeview/folderFavoriteClosed.gif';
folderTextClosed = new Image(22,22);
folderTextClosed.src='/style/Crystal/22/html-menu-treeview/folderTextClosed.gif';
folderLockedClosed = new Image(22,22);
folderLockedClosed.src='/style/Crystal/22/html-menu-treeview/folderLockedClosed.gif';
folderCrystalClosed = new Image(22,22);
folderCrystalClosed.src='/style/Crystal/22/html-menu-treeview/folderCrystalClosed.gif';
folderVideoClosed = new Image(22,22);
folderVideoClosed.src='/style/Crystal/22/html-menu-treeview/folderVideoClosed.gif';
folderPrintClosed = new Image(22,22);
folderPrintClosed.src='/style/Crystal/22/html-menu-treeview/folderPrintClosed.gif';
folderImageClosed = new Image(22,22);
folderImageClosed.src='/style/Crystal/22/html-menu-treeview/folderImageClosed.gif';
folderSoundClosed = new Image(22,22);
folderSoundClosed.src='/style/Crystal/22/html-menu-treeview/folderSoundClosed.gif';
folderImportantClosed = new Image(22,22);
folderImportantClosed.src='/style/Crystal/22/html-menu-treeview/folderImportantClosed.gif';
folderTarClosed = new Image(22,22);
folderTarClosed.src='/style/Crystal/22/html-menu-treeview/folderTarClosed.gif';
